@@ -80,6 +80,9 @@ OC.L10N.register(
     "List" : "Nimekiri",
     "Vertical split" : "Püstjoones jagamine",
     "Horizontal split" : "Rõhtjoones jagamine",
+    "Message View Mode" : "Kirjade vaate liik",
+    "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
+    "Show only the selected message" : "Näita vaid valitud kirja",
     "Sorting" : "Järjestus",
     "Newest" : "Uusim",
     "Oldest" : "Vanim",
@@ -166,9 +169,13 @@ OC.L10N.register(
     "No messages in this mailbox" : "Selles postkastis pole kirju",
     "No messages" : "Kirju pole",
     "No subject" : "Teemat pole",
+    "Later today – {timeLocale}" : "Täna hiljem – {timeLocale}",
     "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
+    "Tomorrow – {timeLocale}" : "Homme – {timeLocale}",
     "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
+    "This weekend – {timeLocale}" : "Sel nädalavahetusel – {timeLocale}",
     "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
+    "Next week – {timeLocale}" : "Järgmisel nädalal – {timeLocale}",
     "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
     "Could not archive message" : "Kirja ei õnnestunud arhiveerida",
     "Thread was unsnoozed" : "Jutulõng on üles äratatud",
@@ -183,8 +190,11 @@ OC.L10N.register(
     "Unimportant" : "Vähetähtis",
     "Edit tags" : "Muuda silte",
     "Move thread" : "Tõsta jutulõng mujale",
+    "Move Message" : "Teisalda kiri",
     "Archive thread" : "Arhiveeri jutulõng",
+    "Archive message" : "Arhiveeri kiri",
     "Delete thread" : "Kustuta jutulõng",
+    "Delete message" : "Kustuta kiri",
     "More actions" : "Täiendavad tegevused",
     "Back" : "Tagasi",
     "Create event" : "Lisa sündmus",
@@ -256,6 +266,7 @@ OC.L10N.register(
     "Show images temporarily" : "Näita pilte ajutiselt",
     "Always show images from {sender}" : "Alati näita pilte {sender} saatjalt",
     "Always show images from {domain}" : "Alati näita pilte {domain} domeenist",
+    "Quoted text" : "Tsiteeritud tekst",
     "Move" : "Liiguta",
     "Moving thread" : "Teisaldan jutulõnga mujale",
     "Moving message" : "Teisaldan kirja",
@@ -303,6 +314,7 @@ OC.L10N.register(
     "Retry" : "Proovi uuesti",
     "Warning sending your message" : "Hoiatus sinu kirja saatmisel",
     "Send anyway" : "Saada ikkagi",
+    "Welcome to {productName} Mail" : "Tere tulemast  kasutama {productName}i Maili",
     "Autoresponder off" : "Automaatvastaja on sees",
     "Autoresponder on" : "Automaatvastaja on väljas",
     "Autoresponder follows system settings" : "Automaatvastaja järgib süsteemi seadistusi",
@@ -391,8 +403,6 @@ OC.L10N.register(
     "Mark as favorite" : "Märgi lemmikuks",
     "Mark as unread" : "Märgi mitteloetuks",
     "Mark as read" : "Märgi loetuks",
-    "Archive message" : "Arhiveeri kiri",
-    "Delete message" : "Kustuta kiri",
     "Thread summary" : "Jutulõnga kokkuvõte",
     "Please select languages to translate to and from" : "Palun vali keeled, mille vahel tahad tõlkida",
     "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
@@ -439,6 +449,8 @@ OC.L10N.register(
     "Allow additional mail accounts" : "Lisa veel e-postikontosid",
     "Allow additional Mail accounts from User Settings" : "Luba kasutaja seadistustest täiendavate e-posti kontode kasutamine",
     "Gmail integration" : "Lõiming Gmailiga",
+    "User Interface Preference Defaults" : "Kasutusliidese eelistuste vaikimisi väärtused",
+    "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "Need on kasutajaliidese eelseadistused, mida iga kasutaja saab oma seadistustest muuta",
     "Reset" : "Lähtesta",
     "Client ID" : "Kliendi ID",
     "Client secret" : "Kliendi salasõna",
@@ -506,9 +518,6 @@ OC.L10N.register(
     "Forwarding to %s" : "Edasta %s",
     "Redirect" : "Suunamine",
     "The link leads to %s" : "Link viitab siia: %s",
-    "Continue to %s" : "Jätka siit: %s",
-    "Collapse composer" : "Ahenda kirjutusvaade",
-    "Uploading attachments …" : "Manused on üleslaadimisel…",
-    "Sending …" : "Saadan..."
+    "Continue to %s" : "Jätka siit: %s"
 },
 "nplurals=2; plural=(n != 1);");
