@@ -223,7 +223,9 @@ OC.L10N.register(
     "Unsnooze" : "다시 알림 해제",
     "Move thread" : "쓰레드 이동",
     "Archive thread" : "쓰레드 보관",
+    "Archive message" : "메시지 보관",
     "Delete thread" : "쓰레드 삭제",
+    "Delete message" : "메시지 삭제",
     "More actions" : "더 많은 동작",
     "Back" : "뒤로",
     "Set custom snooze" : "사용자 지정 다시 알림 사용",
@@ -468,8 +470,6 @@ OC.L10N.register(
     "Mark as favorite" : "즐겨찾기로 표시",
     "Mark as unread" : "읽지 않은 것으로 표시",
     "Mark as read" : "읽은 것으로 표시",
-    "Archive message" : "메시지 보관",
-    "Delete message" : "메시지 삭제",
     "Message source" : "메시지 원본",
     "Unsubscribe via link" : "링크로 구독 해지",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "구독 해지는 메일링 리스트 {sender}이(가) 보내는 모든 메시지의 발신을 정지합니다",
@@ -643,8 +643,6 @@ OC.L10N.register(
     "Redirect" : "넘겨주기",
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
-    "Continue to %s" : "%s(으)로 이동",
-    "Uploading attachments …" : "첨부 파일 업로드...",
-    "Sending …" : "보내는 중..."
+    "Continue to %s" : "%s(으)로 이동"
 },
 "nplurals=1; plural=0;");
